package com.yijia.market.service;

import java.util.List;
import com.yijia.market.domain.MarketCoupon;

/**
 * 优惠劵管理Service接口
 * 
 * @author yijia
 * @date 2020-12-22
 */
public interface IMarketCouponService 
{
    /**
     * 查询优惠劵管理
     * 
     * @param couponId 优惠劵管理ID
     * @return 优惠劵管理
     */
    public MarketCoupon selectMarketCouponById(Long couponId);

    /**
     * 查询优惠劵管理列表
     * 
     * @param marketCoupon 优惠劵管理
     * @return 优惠劵管理集合
     */
    public List<MarketCoupon> selectMarketCouponList(MarketCoupon marketCoupon);

    /**
     * 新增优惠劵管理
     * 
     * @param marketCoupon 优惠劵管理
     * @return 结果
     */
    public int insertMarketCoupon(MarketCoupon marketCoupon);

    /**
     * 修改优惠劵管理
     * 
     * @param marketCoupon 优惠劵管理
     * @return 结果
     */
    public int updateMarketCoupon(MarketCoupon marketCoupon);

    /**
     * 批量删除优惠劵管理
     * 
     * @param couponIds 需要删除的优惠劵管理ID
     * @return 结果
     */
    public int deleteMarketCouponByIds(Long[] couponIds);

    /**
     * 删除优惠劵管理信息
     * 
     * @param couponId 优惠劵管理ID
     * @return 结果
     */
    public int deleteMarketCouponById(Long couponId);
}
